==> zio-aws-datasync_3-5.17.183.1-sources.jar: zio/aws/datasync/model/DescribeLocationEfsResponse.scala <==
package zio.aws.datasync.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.datasync.model.primitives.{Time, LocationUri, LocationArn}
import scala.jdk.CollectionConverters.*
final case class DescribeLocationEfsResponse(
    locationArn: Optional[LocationArn] = Optional.Absent,
    locationUri: Optional[LocationUri] = Optional.Absent,
    ec2Config: Optional[zio.aws.datasync.model.Ec2Config] = Optional.Absent,
    creationTime: Optional[Time] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse = {
    import DescribeLocationEfsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .optionallyWith(
        locationUri.map(value => LocationUri.unwrap(value): java.lang.String)
      )(_.locationUri)
      .optionallyWith(ec2Config.map(value => value.buildAwsValue()))(
        _.ec2Config
      )
      .optionallyWith(creationTime.map(value => Time.unwrap(value): Instant))(
        _.creationTime
      )
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly =
    zio.aws.datasync.model.DescribeLocationEfsResponse.wrap(buildAwsValue())
}
object DescribeLocationEfsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.DescribeLocationEfsResponse =
      zio.aws.datasync.model.DescribeLocationEfsResponse(
        locationArn.map(value => value),
        locationUri.map(value => value),
        ec2Config.map(value => value.asEditable),
        creationTime.map(value => value)
      )
    def locationArn: Optional[LocationArn]
    def locationUri: Optional[LocationUri]
    def ec2Config: Optional[zio.aws.datasync.model.Ec2Config.ReadOnly]
    def creationTime: Optional[Time]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
    def getLocationUri: ZIO[Any, AwsError, LocationUri] =
      AwsError.unwrapOptionField("locationUri", locationUri)
    def getEc2Config
        : ZIO[Any, AwsError, zio.aws.datasync.model.Ec2Config.ReadOnly] =
      AwsError.unwrapOptionField("ec2Config", ec2Config)
    def getCreationTime: ZIO[Any, AwsError, Time] =
      AwsError.unwrapOptionField("creationTime", creationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ) extends zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly {
    override val locationArn: Optional[LocationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
    override val locationUri: Optional[LocationUri] = zio.aws.core.internal
      .optionalFromNullable(impl.locationUri())
      .map(value => zio.aws.datasync.model.primitives.LocationUri(value))
    override val ec2Config
        : Optional[zio.aws.datasync.model.Ec2Config.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ec2Config())
        .map(value => zio.aws.datasync.model.Ec2Config.wrap(value))
    override val creationTime: Optional[Time] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.datasync.model.primitives.Time(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ): zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datasync_3-7.21.15.4-sources.jar: zio/aws/datasync/model/DescribeLocationEfsResponse.scala <==
package zio.aws.datasync.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.datasync.model.primitives.{
  Time,
  IamRoleArn,
  EfsAccessPointArn,
  LocationArn,
  LocationUri
}
import scala.jdk.CollectionConverters.*
final case class DescribeLocationEfsResponse(
    locationArn: Optional[LocationArn] = Optional.Absent,
    locationUri: Optional[LocationUri] = Optional.Absent,
    ec2Config: Optional[zio.aws.datasync.model.Ec2Config] = Optional.Absent,
    creationTime: Optional[Time] = Optional.Absent,
    accessPointArn: Optional[EfsAccessPointArn] = Optional.Absent,
    fileSystemAccessRoleArn: Optional[IamRoleArn] = Optional.Absent,
    inTransitEncryption: Optional[
      zio.aws.datasync.model.EfsInTransitEncryption
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse = {
    import DescribeLocationEfsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .optionallyWith(
        locationUri.map(value => LocationUri.unwrap(value): java.lang.String)
      )(_.locationUri)
      .optionallyWith(ec2Config.map(value => value.buildAwsValue()))(
        _.ec2Config
      )
      .optionallyWith(creationTime.map(value => Time.unwrap(value): Instant))(
        _.creationTime
      )
      .optionallyWith(
        accessPointArn.map(value =>
          EfsAccessPointArn.unwrap(value): java.lang.String
        )
      )(_.accessPointArn)
      .optionallyWith(
        fileSystemAccessRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.fileSystemAccessRoleArn)
      .optionallyWith(inTransitEncryption.map(value => value.unwrap))(
        _.inTransitEncryption
      )
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly =
    zio.aws.datasync.model.DescribeLocationEfsResponse.wrap(buildAwsValue())
}
object DescribeLocationEfsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.DescribeLocationEfsResponse =
      zio.aws.datasync.model.DescribeLocationEfsResponse(
        locationArn.map(value => value),
        locationUri.map(value => value),
        ec2Config.map(value => value.asEditable),
        creationTime.map(value => value),
        accessPointArn.map(value => value),
        fileSystemAccessRoleArn.map(value => value),
        inTransitEncryption.map(value => value)
      )
    def locationArn: Optional[LocationArn]
    def locationUri: Optional[LocationUri]
    def ec2Config: Optional[zio.aws.datasync.model.Ec2Config.ReadOnly]
    def creationTime: Optional[Time]
    def accessPointArn: Optional[EfsAccessPointArn]
    def fileSystemAccessRoleArn: Optional[IamRoleArn]
    def inTransitEncryption
        : Optional[zio.aws.datasync.model.EfsInTransitEncryption]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
    def getLocationUri: ZIO[Any, AwsError, LocationUri] =
      AwsError.unwrapOptionField("locationUri", locationUri)
    def getEc2Config
        : ZIO[Any, AwsError, zio.aws.datasync.model.Ec2Config.ReadOnly] =
      AwsError.unwrapOptionField("ec2Config", ec2Config)
    def getCreationTime: ZIO[Any, AwsError, Time] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getAccessPointArn: ZIO[Any, AwsError, EfsAccessPointArn] =
      AwsError.unwrapOptionField("accessPointArn", accessPointArn)
    def getFileSystemAccessRoleArn: ZIO[Any, AwsError, IamRoleArn] = AwsError
      .unwrapOptionField("fileSystemAccessRoleArn", fileSystemAccessRoleArn)
    def getInTransitEncryption
        : ZIO[Any, AwsError, zio.aws.datasync.model.EfsInTransitEncryption] =
      AwsError.unwrapOptionField("inTransitEncryption", inTransitEncryption)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ) extends zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly {
    override val locationArn: Optional[LocationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
    override val locationUri: Optional[LocationUri] = zio.aws.core.internal
      .optionalFromNullable(impl.locationUri())
      .map(value => zio.aws.datasync.model.primitives.LocationUri(value))
    override val ec2Config
        : Optional[zio.aws.datasync.model.Ec2Config.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ec2Config())
        .map(value => zio.aws.datasync.model.Ec2Config.wrap(value))
    override val creationTime: Optional[Time] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.datasync.model.primitives.Time(value))
    override val accessPointArn: Optional[EfsAccessPointArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accessPointArn())
        .map(value =>
          zio.aws.datasync.model.primitives.EfsAccessPointArn(value)
        )
    override val fileSystemAccessRoleArn: Optional[IamRoleArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fileSystemAccessRoleArn())
        .map(value => zio.aws.datasync.model.primitives.IamRoleArn(value))
    override val inTransitEncryption
        : Optional[zio.aws.datasync.model.EfsInTransitEncryption] =
      zio.aws.core.internal
        .optionalFromNullable(impl.inTransitEncryption())
        .map(value => zio.aws.datasync.model.EfsInTransitEncryption.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.DescribeLocationEfsResponse
  ): zio.aws.datasync.model.DescribeLocationEfsResponse.ReadOnly = new Wrapper(
    impl
  )
}
